Authentication
==============

Classes for the DBus `authentication protocol <https://dbus.freedesktop.org/doc/dbus-specification.html#auth-protocol>`_ for us with :class:`MessageBus <asyncdbus.message_bus.MessageBus>` implementations.

.. autoclass:: asyncdbus.auth.Authenticator

.. autoclass:: asyncdbus.auth.AuthExternal
.. autoclass:: asyncdbus.auth.AuthAnnonymous
